# Keras WhatApp chat model (KWaddle)

Small Python library to perform machine learning on Whatsapp chat logs.

To-be-implemented:
* Skip-gram to estimate character embeddings from a chat
* Next-character prediction RNN